// This file is part of Gopher2600.
//
// Gopher2600 is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Gopher2600 is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Gopher2600.  If not, see <https://www.gnu.org/licenses/>.

// Package prefs facilitates the storage of preferential values in the
// Gopher2600 system. It is a key/value system and is quite flexible. The most
// significant feature is the ability to only specify the preferences you are
// interested in for a given task. Loading and saving a preference will ignore
// and preserve values that haven't been added to the "Disk" type.
//
// The Disk type is the key resource in the package. First, create new Disk
// instance with NewDisk(), specifying the location of the preferences file
// (using paths.ResourcePath() as necessary).
//
//	fn, _ := paths.ResourcePath(prefs.DefaultPrefsFile)
//	prf := prefs.NewDisk(fn)
//
// Preference value can then be added with the Add() function, specifying the
// "key" value. For clarity, the key value should be similar to the name of the
// variable as used in the calling code, although this isn't required (note the
// restrictions on the key value in the documtation for the Add() function).
//
//	prf.Add("auto", &auto)
//
// Values that are added to the Disk type must use one of the preference types
// defined in this package. Currently, there are Bool, String and Int types.
// There is also a Generic type, that allows the Set() and Get() functions to
// be defined.
//
// Once added to the disk object, preference values can be changed in the
// program in the normal way. Changes can be committed to disk wit the
// Disk.Save() function and restoried with Disk.Load().
//
//Note
//
// While saved preference files are stored in UTF-8 it is not a good idea for
// the files to be edited by hand. As such, manual editing is discorouaged with
// the warning at the top of the file:
//
//	*** do not edit this file by hand ***
//
// This also serves as the means of identification for the Load() function. ie.
// if this warning is not present then the Load() operation will fail.
package prefs
